@@ -1,5 +1,4 @@
 #!/usr/bin/perl -w
-
 use integer;
 
 # The following make this program more readable.
@@ -30,13 +29,8 @@ $BackedUpListLookingForBlankLine = $No;
 $BackedUpListLookingForDirectoryName = $No;
 $NewFilesOnly = $No;
 $DebugPerlMatches = $No;
-$LimitNumberOfFilesInArchive = $No;
-$NumberOfFilesInArchive = 0;
-$LimitSizeOfArchive = $No;
-$SizeOfArchive = 0;
 $StartedReadingBackedUpList = $No;
 $StartedReadingCurrentList = $No;
-$BigFilesOnly = $No;
 $IgnoreDirectories = $No;
 
 # these initializations are needed
@@ -45,29 +39,13 @@ $BackedUpListLookingForTotalOrFirstFile = $Yes;
 
 #print("@ARGV\n");
 
-if ( $#ARGV < 7 ) {
+if ( $#ARGV < 6 ) {
   print "not enough command line parameters\n";
   exit 11;
   }
 
-if (!open(FH_DirExcFile,"<$ARGV[0]")) {
-  print "unable to open directory exclude file $ARGV[0]\n";
-  exit 12;
-  }
-$DirectoryExcludesCount = 0;
-while (<FH_DirExcFile>) {
-  next if m/^\$/;  # if the first character is '$', ignore the line
-  next if m/^$/;  # if the line is blank, ignore the line
-  $DirectoryExcludes[$DirectoryExcludesCount] = $_;
-  $DirectoryExcludesCount = $DirectoryExcludesCount + 1;
-  }
-close(FH_DirExcFile);
-#print("number of directory excludes is $DirectoryExcludesCount\n");
-#print(@DirectoryExcludes);
-chomp(@DirectoryExcludes);
-
-if (!open(FH_IncExcFile,"<$ARGV[1]")) {
-  print "unable to open include/exclude file $ARGV[1]\n";
+if (!open(FH_IncExcFile,"<$ARGV[0]")) {
+  print "unable to open include/exclude file $ARGV[0]\n";
   exit 13;
   }
 $IncExcPatternCount = 0;
@@ -86,38 +64,38 @@ while (<FH_IncExcFile>) {
 close(FH_IncExcFile);
 chomp(@IncExcPatterns);
 
-if (!open(FH_CurrentList,"<$ARGV[2]")) {
-  print "unable to open current files list file $ARGV[2]\n";
+if (!open(FH_CurrentList,"<$ARGV[1]")) {
+  print "unable to open current files list file $ARGV[1]\n";
   exit 14;
   }
 
-if (!open(FH_BackedUpList,"<$ARGV[3]")) {
-  print "unable to open backed up files list file $ARGV[3]\n";
+if (!open(FH_BackedUpList,"<$ARGV[2]")) {
+  print "unable to open backed up files list file $ARGV[2]\n";
   exit 15;
   }
 
-if (!open(FH_ModifiedBackedUpList,">>$ARGV[4]")) {
-  print "unable to open modified backed up files list file $ARGV[4]\n";
+if (!open(FH_ModifiedBackedUpList,">>$ARGV[3]")) {
+  print "unable to open modified backed up files list file $ARGV[3]\n";
   exit 16;
   }
 
-if (!open(FH_DeletedFileList,">>$ARGV[5]")) {
-  print "unable to open deleted files list file $ARGV[5]\n";
+if (!open(FH_DeletedFileList,">>$ARGV[4]")) {
+  print "unable to open deleted files list file $ARGV[4]\n";
   exit 17;
   }
 
-if (!open(FH_FilesToBackUpList,">>$ARGV[6]")) {
-  print "unable to open list of files to back up file $ARGV[6]\n";
+if (!open(FH_FilesToBackUpList,">>$ARGV[5]")) {
+  print "unable to open list of files to back up file $ARGV[5]\n";
   exit 18;
   }
 
-if (!open(FH_FilesToBackUpListLs,">>$ARGV[7]")) {
+if (!open(FH_FilesToBackUpListLs,">>$ARGV[6]")) {
   print "unable to open list of files to back up file, ls format:\n",
-              "$ARGV[7]\n";
+              "$ARGV[6]\n";
   exit 19;
   }
 
-$A = 7;
+$A = 6;
 while ( $A < $#ARGV ) {
   $A = $A + 1;
   #print("current option is $ARGV[$A]\n");
@@ -140,30 +118,6 @@ while ( $A < $#ARGV ) {
       }
     next;
     }
-  #print substr($ARGV[$A],0,23);print("\n");
-  if (substr($ARGV[$A],0,23) eq '--MaxNumFilesInArchive=') {
-    $MaximumNumberOfFilesInArchive = substr($ARGV[$A],23);
-    #print("max files is $MaximumNumberOfFilesInArchive\n");
-    if ( $MaximumNumberOfFilesInArchive != 0 ) {
-      $LimitNumberOfFilesInArchive = $Yes;
-      }
-    next;
-    }
-  if (substr($ARGV[$A],0,19) eq '--MaxSizeOfArchive=') {
-    $MaximumSizeOfArchive = substr($ARGV[$A],19);
-    if ( $MaximumSizeOfArchive != 0 ) {
-      $LimitSizeOfArchive = $Yes;
-      }
-    next;
-    }
-  if (substr($ARGV[$A],0,15) eq '--BigFilesOnly=') {
-    $MinumumSizeOfFile = substr($ARGV[$A],15);
-    if ( $MinumumSizeOfFile != 0 ) {
-      $BigFilesOnly = $Yes;
-      }
-    #print("minimum size of file is $MinumumSizeOfFile\n");
-    next;
-    }
   print("CompareFileLists does not understand the following command line option:\n",
         "$ARGV[$A]\n");
   exit 9;
@@ -214,10 +168,13 @@ if ( $A == 1 ) {
   goto L_DeletedFile;
   }
 # If we got to here, the directory names must match
+#print("$BackedUpListThisLine\n");
+#print("$CurrentListThisLine\n");
 if ( $CurrentListThisLine eq $BackedUpListThisLine ) {
   goto L_UnchangedFile;
   }
 $A = $CurrentListThisFileName cmp $BackedUpListThisFileName;
+#print("$A\n");
 if ( $A == 0 ) {
   goto L_ChangedFile;
   }
@@ -229,10 +186,11 @@ if ( $A == 1 ) {
   # $BackedUpListThisFileName comes before $CurrentListThisFileName
   goto L_DeletedFile;
   }
-print("impossible error, cmp returned something other than 1, 0, or -1\n");
+print("bug detected, cmp() returned something other than 1, 0, or -1\n");
 exit 40;
 
 L_UnchangedFile:
+#print("unchanged file\n");
 # should we check to see if the file is included? maybe it got
 # backed up before, but the user changed the include exclude
 # criteria so it is now excluded; in which case we might want
@@ -250,19 +208,23 @@ print(FH_ModifiedBackedUpList $BackedUpListThisLine,"\n");
 goto L_CompareNow;
 
 L_ChangedFile:
+#print("changed file\n");
 if ( $NewFilesOnly == $Yes ) {
   goto L_UnchangedFile;
   }
 $SA = substr($CurrentListThisLine,0,1);
 if ( $SA eq 'd'    or    $SA eq 'p' ) {
-  # if it is a directory, and the ls listing has changed, but the
+  # if it is a directory or pipe, and the ls listing has changed, but the
   # permissions, owner, and group have not changed, then treat it as
-  # unchanged. A directory is not changed unless the permissions, owner,
-  # or group changes. Also do the same for named pipes.
+  # unchanged.
   # This does not check for the spaces which mark the beginning and the end
   # of the uid and gid, so there may be trouble if the uid and gid are not
   # in the expected position. But I think that this is not likely to be a
   # problem, so I have not bothered to fix this potential bug.
+  #print(substr($CurrentListThisLine,0,11),"\n");
+  #print(substr($BackedUpListThisLine,0,11),"\n");
+  #print(substr($CurrentListThisLine,15,18),"\n");
+  #print(substr($BackedUpListThisLine,15,18),"\n");
   if (
     substr($CurrentListThisLine,0,11) eq substr($BackedUpListThisLine,0,11)
         and
@@ -306,47 +268,6 @@ else {
 if ( &isFileNameIncluded($FullFileName) == $Exclude ) {
   goto L_UnchangedFile;
   }
-if ( $BigFilesOnly == $Yes ) {
-  if ( &getFileSizeFromLSline($CurrentListThisLine) <
-                     $MinumumSizeOfFile ) {
-    goto L_UnchangedFile;
-    }
-  }
-$NumberOfFilesInArchive = $NumberOfFilesInArchive + 1;
-if ( $LimitNumberOfFilesInArchive == $Yes ) {
-  if ( $NumberOfFilesInArchive > $MaximumNumberOfFilesInArchive ) {
-    if ( $EndOfBackedUpList == $No ) {
-      print(FH_ModifiedBackedUpList $BackedUpListThisLine,"\n");
-      while (<FH_BackedUpList>) {
-        print(FH_ModifiedBackedUpList $_);
-        }
-      }
-    exit 1;
-    }
-  }
-if ( $LimitSizeOfArchive == $Yes ) {
-  #print("checking size of archive\n");
-  $SizeOfArchive = $SizeOfArchive +
-                   &getFileSizeFromLSline($CurrentListThisLine);
-  if ( $SizeOfArchive > $MaximumSizeOfArchive ) {
-    #print("archive is too big\n");
-    #print("number of files in archive is $NumberOfFilesInArchive\n");
-    if ( $NumberOfFilesInArchive == 1 ) {
-      print("Error:\n$CurrentListThisLine\n",
-          "in $CurrentListThisDirectory\n",
-          "is too large for maximum archive size of $MaximumSizeOfArchive\n");
-      exit 10
-      }
-    if ( $EndOfBackedUpList == $No ) {
-      #print("finishing backed up list\n");
-      print(FH_ModifiedBackedUpList $BackedUpListThisLine,"\n");
-      while (<FH_BackedUpList>) {
-        print(FH_ModifiedBackedUpList $_);
-        }
-      }
-    exit 1;
-    }
-  }
 if ( $ModifiedBackedUpListThisDirectory ne $CurrentListThisDirectory ) {
   print(FH_ModifiedBackedUpList "\n",$CurrentListThisDirectory,":\n");
   $ModifiedBackedUpListThisDirectory = $CurrentListThisDirectory;
@@ -370,6 +291,7 @@ else {
 goto L_CompareNow;
 
 L_DeletedFile:
+#print("deleted file\n");
 # the file from backed up list is not in the current list;
 # it must have been deleted since the last backup
 if ( $NewFilesOnly == $Yes ) {
@@ -392,6 +314,7 @@ else {
 goto L_CompareNow;
 
 L_NewFile:
+#print("new file\n");
 # the file from current list is not in the backed up list;
 # it must have been created since the last backup
 # or else it was excluded from the last backup
@@ -405,44 +328,6 @@ if ( &isFileNameIncluded($FullFileName) == $Exclude ) {
   &getNextLineFromCurrentList;
   goto L_CompareNow;
   }
-if ( $BigFilesOnly == $Yes ) {
-  if ( &getFileSizeFromLSline($CurrentListThisLine) <
-                     $MinumumSizeOfFile ) {
-    &getNextLineFromCurrentList;
-    goto L_CompareNow;
-    }
-  }
-$NumberOfFilesInArchive = $NumberOfFilesInArchive + 1;
-if ( $LimitNumberOfFilesInArchive == $Yes ) {
-  if ( $NumberOfFilesInArchive > $MaximumNumberOfFilesInArchive ) {
-    if ( $EndOfBackedUpList == $No ) {
-      print(FH_ModifiedBackedUpList $BackedUpListThisLine,"\n");
-      while (<FH_BackedUpList>) {
-        print(FH_ModifiedBackedUpList $_);
-        }
-      }
-    exit 1;
-    }
-  }
-if ( $LimitSizeOfArchive == $Yes ) {
-  $SizeOfArchive = $SizeOfArchive +
-                   &getFileSizeFromLSline($CurrentListThisLine);
-  if ( $SizeOfArchive > $MaximumSizeOfArchive ) {
-    if ( $NumberOfFilesInArchive == 1 ) {
-      print("Error:\n$CurrentListThisLine\n",
-          "in $CurrentListThisDirectory\n",
-          "is too large for maximum archive size of $MaximumSizeOfArchive\n");
-      exit 10
-      }
-    if ( $EndOfBackedUpList == $No ) {
-      print(FH_ModifiedBackedUpList $BackedUpListThisLine,"\n");
-      while (<FH_BackedUpList>) {
-        print(FH_ModifiedBackedUpList $_);
-        }
-      }
-    exit 1;
-    }
-  }
 if ( $ModifiedBackedUpListThisDirectory ne $CurrentListThisDirectory ) {
   print(FH_ModifiedBackedUpList "\n",$CurrentListThisDirectory,":\n");
   $ModifiedBackedUpListThisDirectory = $CurrentListThisDirectory;
@@ -518,16 +403,15 @@ sub getNextLineFromCurrentList {
   if ( $CurrentListLookingForDirectoryName == $Yes ) {
     if ( substr($CurrentListThisLine,-1) eq ':' ) {
       $SA = substr($CurrentListThisLine,0,-1);
-      if ( &directoryExclude($SA) == $Exclude ) {
-        $CurrentListLookingForBlankLine = $Yes;
-        goto L_getNextLineFromCurrentListStart;
+      if ( substr($SA,0,2) eq './' )  {
+        $SA = substr($SA,2);
         }
       $CurrentListPreviousDirectory = $CurrentListThisDirectory;
       $CurrentListThisDirectory = $SA;
       $A = &directoryNameCompare($CurrentListThisDirectory,
                                  $CurrentListPreviousDirectory);
       if ( $A == 0 ) {
-        print("Error in current file list: $ARGV[2]\n",
+        print("Error in current file list: $ARGV[1]\n",
               "line $CurrentListLineCount.\n",
               "The current directory is '$CurrentListThisDirectory'\n",
               "The previous directory is '$CurrentListPreviousDirectory'\n",
@@ -535,7 +419,7 @@ sub getNextLineFromCurrentList {
         exit 30;
         }
       if ( $A == -1 ) {
-        print("Error in current file list: $ARGV[2]\n",
+        print("Error in current file list: $ARGV[1]\n",
               "line $CurrentListLineCount. Perl thinks directory\n",
               "'$CurrentListThisDirectory'\n",
               "should come before directory\n",
@@ -547,7 +431,7 @@ sub getNextLineFromCurrentList {
       $CurrentListLookingForTotalOrFirstFile = $Yes;
       goto L_getNextLineFromCurrentListStart;
       }
-    print("Error in current file list: $ARGV[2]\n",
+    print("Error in current file list: $ARGV[1]\n",
           "line $CurrentListLineCount.\n",
           "This line should end with a colon, ':', ",
           "because it comes after a blank line:\n",
@@ -562,7 +446,7 @@ sub getNextLineFromCurrentList {
     }
   $CurrentListThisFileName = &getFileNameFromLSline($CurrentListThisLine);
   if ( $CurrentListThisFileName eq '') {
-    print("Error in current file list: $ARGV[2]\n",
+    print("Error in current file list: $ARGV[1]\n",
           "line $CurrentListLineCount.\n",
           "This line does not contain a file name, ",
           "and is not blank either:\n",
@@ -581,7 +465,7 @@ sub getNextLineFromCurrentList {
     }
   if ( $A == -1 ) {
     # $CurrentListThisFileName comes before $CurrentListPreviousFileName
-    print("Error in current file list: $ARGV[2]\n",
+    print("Error in current file list: $ARGV[1]\n",
           "line $CurrentListLineCount.\n",
           "The lines are not in a perl compatible order.\n",
           "Perl thinks '$CurrentListThisFileName'\n",
@@ -593,14 +477,14 @@ sub getNextLineFromCurrentList {
     }
   if ( $A == 0 ) {
     # file names are the same
-    print("Error in current file list: $ARGV[2]\n",
+    print("Error in current file list: $ARGV[1]\n",
           "line $CurrentListLineCount. The filename from the current line\n",
           "is '$CurrentListThisFileName'. The filename from\n",
           "the previous line is '$CurrentListPreviousFileName'\n",
           "Perl thinks these filenames are the same.\n");
     exit 30;
     }
-  print("impossible error, cmp returned something other than 1, 0, or -1\n");
+  print("bug detected, cmp returned something other than 1, 0, or -1\n");
   exit 40;
   }
 
@@ -648,9 +532,8 @@ sub getNextLineFromBackedUpList {
   if ( $BackedUpListLookingForDirectoryName == $Yes ) {
     if ( substr($BackedUpListThisLine,-1) eq ':' ) {
       $SA = substr($BackedUpListThisLine,0,-1);
-      if ( &directoryExclude($SA) == $Exclude ) {
-        $BackedUpListLookingForBlankLine = $Yes;
-        goto L_getNextLineFromBackedUpListStart;
+      if ( substr($SA,0,2) eq './' )  {
+        $SA = substr($SA,2);
         }
       $BackedUpListPreviousDirectory = $BackedUpListThisDirectory;
       $BackedUpListThisDirectory = $SA;
@@ -658,7 +541,7 @@ sub getNextLineFromBackedUpList {
       $A = &directoryNameCompare($BackedUpListThisDirectory,
                                  $BackedUpListPreviousDirectory);
       if ( $A == 0 ) {
-        print("Error in backed up file list $ARGV[3]\n",
+        print("Error in backed up file list $ARGV[2]\n",
               "line $BackedUpListLineCount.\n",
               "The current directory is '$BackedUpListThisDirectory'\n",
               "The previous directory is '$BackedUpListPreviousDirectory'\n",
@@ -666,7 +549,7 @@ sub getNextLineFromBackedUpList {
         exit 31;
         }
       if ( $A == -1 ) {
-        print("Error in backed up file list $ARGV[3]\n",
+        print("Error in backed up file list $ARGV[2]\n",
               "line $BackedUpListLineCount. Perl thinks directory\n",
               "'$BackedUpListThisDirectory'\n",
               "should come before directory\n",
@@ -681,7 +564,7 @@ sub getNextLineFromBackedUpList {
       $BackedUpListLookingForTotalOrFirstFile = $Yes;
       goto L_getNextLineFromBackedUpListStart;
       }
-    print("Error in backed up file list: $ARGV[3]\n",
+    print("Error in backed up file list: $ARGV[2]\n",
           "line $BackedUpListLineCount.\n",
           "This line should end with a colon, ':', ",
           "because it comes after a blank line:\n",
@@ -696,7 +579,7 @@ sub getNextLineFromBackedUpList {
     }
   $BackedUpListThisFileName = &getFileNameFromLSline($BackedUpListThisLine);
   if ( $BackedUpListThisFileName eq '') {
-    print("Error in backed up file list: $ARGV[3]\n",
+    print("Error in backed up file list: $ARGV[2]\n",
           "line $BackedUpListLineCount.\n",
           "This line does not contain a file name, ",
           "and is not blank either:\n",
@@ -715,7 +598,7 @@ sub getNextLineFromBackedUpList {
     }
   if ( $A == -1 ) {
     # $BackedUpListThisFileName comes before $BackedUpListPreviousFileName
-    print("Error in backed up file list: $ARGV[3]\n",
+    print("Error in backed up file list: $ARGV[2]\n",
           "line $BackedUpListLineCount.\n",
           "The lines are not in a perl compatible order.\n",
           "Perl thinks '$BackedUpListThisFileName'\n",
@@ -727,37 +610,18 @@ sub getNextLineFromBackedUpList {
     }
   if ( $A == 0 ) {
     # file names are the same
-    print("Error in backed up file list: $ARGV[3]\n",
+    print("Error in backed up file list: $ARGV[2]\n",
           "line $BackedUpListLineCount. The filename from the current line\n",
           "is '$BackedUpListThisFileName'. The filename from\n",
           "the previous line is '$BackedUpListPreviousFileName'\n",
           "Perl thinks these filenames are the same.\n");
     exit 31;
     }
-  print("impossible error, cmp returned something other than 1, 0, or -1\n");
+  print("bug detected, cmp returned something other than 1, 0, or -1\n");
   exit 40;
   }
 
 
-sub directoryExclude {
-  #print(STDERR "sub directory excludes\n");
-  for(@DirectoryExcludes) {
-    if ( $_[0] =~ m/$_/ ) {
-      if ( $DebugPerlMatches == $Yes ) {
-        print(FH_DebugPerlMatches "$_[0] matches $_, directory excluded\n");
-        #print("$_[0] matches $_, directory excluded\n");
-        }
-      return($Exclude);
-      }
-    elsif ( $DebugPerlMatches == $Yes )
-        { print(FH_DebugPerlMatches "$_[0] does not match $_\n") }
-    }
-  if ( $DebugPerlMatches == $Yes ) {
-    print(FH_DebugPerlMatches "no matches for $_[0], directory included\n");
-    }
-  return($Include);
-  }
-
 sub isFileNameIncluded  {
   # start with the last pattern
   $IncExcPatternCount = $#IncludeOrExclude;
@@ -925,19 +789,6 @@ sub directoryNameCompare  {
     }
   }
 
-sub getFileSizeFromLSline  {
-  # if the first character is '-' then it is a regular file; return the
-  # file size
-  #print(substr($_[0],0,1));print("   ");print(substr($_[0],33,8));
-  #print("   ");print(substr($_[0],33,8) + 1);print("\n");
-  return(substr($_[0],33,8)) if ( substr($_[0],0,1) eq '-' );
-  # otherwise it must be a block or character device, pipe, link,
-  # or something like that; return 0
-  return(0);
-  }
-
-
-
 
 __END__
 
@@ -954,16 +805,15 @@ This perl script compares two file lists and makes a list of files to be
 backed up.
 
 command line parameters should be:
- $ARGV[0]    input, file name, directory exclude patterns
- $ARGV[1]    input, file name, include exclude patterns
- $ARGV[2]    input, file name, current file list
- $ARGV[3]    input, file name, backed up file list
- $ARGV[4]    output, file name, modified backed up file list
- $ARGV[5]    output, file name, list of files to be removed from old
+ $ARGV[0]    input, file name, include exclude patterns
+ $ARGV[1]    input, file name, current file list
+ $ARGV[2]    input, file name, backed up file list
+ $ARGV[3]    output, file name, modified backed up file list
+ $ARGV[4]    output, file name, list of files to be removed from old
              backups (deleted or changed files)
- $ARGV[6]    output, file name, list of files to be backed up (new or
+ $ARGV[5]    output, file name, list of files to be backed up (new or
              changed files)
- $ARGV[7]    output, like $ARGV[6] but in ls long format
+ $ARGV[6]    output, like $ARGV[5] but in ls long format
 
 additional optional parameters:
        --IgnoreDirectories
@@ -975,9 +825,7 @@ exit codes:
  1    max size of archive reached
 
  9    incorrect command line option
-10    archive too big when no files have been selected
 11    not enough command line parameters
-12    unable to read directory excludes file
 13    unable to read include/exclude list filed
 14    unable to read current files list file
 15    unable to read backed up files list file
@@ -989,7 +837,7 @@ exit codes:
 30    current files list not in expected format
 31    backed up files list not in expected format
 
-40    impossible error (cmp returned something other than 1,0, or -1)
+40    bug detected
 
 code which has been commented out with no space after the '#'
 is debugging code, which has been left in place in case it is needed
@@ -1040,13 +888,3 @@ corresponding code to the second part. It could also remove code for
 unused options. Then the second part would run. Then the second part
 would be deleted. The next time you want to run it, the first part would
 create the second part again.
-
-
-The sub getFileSizeFromLSline does not care that the location of the file
-size in the ls line will be changed if there are more than 999 hard links,
-if the file size is more than 99,999,999 bytes, etc. In these cases, it will
-not get the correct file size. I have not bothered to fix this bug because
-the sub getFileSizeFromLSline is only used if we use options
---MaxNumFilesInArchive, --MaxSizeOfArchive, or --BigFilesOnly; and after I
-created these options, I decided these options were useless and should be
-removed; but I was too lazy to remove them or fix the bugs in them.
