@@ -464,10 +464,11 @@ mdti.mdisks.pl:  unable to open and write to the file named \'index\'
 ") }
   }
 
-if ( defined($StopCommands) )
-    { system($StopCommands)    and    print(STDERR "
+if ( defined($StopCommands) )   { if ( $StopCommands ne '' )  {
+    $NA = system($StopCommands);
+    if ( $NA != 0 )  { print(STDERR "
 mdti.mdisks.pl: stop commands '$StopCommands'
-returned an exit code of ", $NA/256, "\n") }
+returned $NA; exit code was ", $NA/256, "\n") }}}
 
 unlink('commands','data');
 exit($_[0]);
